/*
 * Copyright (C) 2004 emuWorks
 * http://games.technoplaza.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package chtdecoder.view;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;

import java.awt.dnd.DnDConstants;
import java.awt.dnd.DropTarget;
import java.awt.dnd.DropTargetDragEvent;
import java.awt.dnd.DropTargetDropEvent;
import java.awt.dnd.DropTargetEvent;
import java.awt.dnd.DropTargetListener;

import java.io.File;

import java.util.Iterator;
import java.util.List;

import javax.swing.JList;
import javax.swing.ListModel;

/**
 * An extended JList with support for .CHT file DragNDrop.
 *
 * @author John David Ratliff
 * @version 1.1, 09/27/04
 */
public class CHTDropList extends JList implements DropTargetListener {
    private CHTApplet parent;

    /**
     * Creates a new CHTDropList object.
     *
     * @param parent The CHTApplet parent of this List.
     * @param model The ListModel to use.
     */
    protected CHTDropList(CHTApplet parent, ListModel model) {
        super();

        this.setModel(model);
        this.parent = parent;

        new DropTarget(this, DnDConstants.ACTION_COPY_OR_MOVE, this);
    }

    /**
     * Callback when files are dropped on this DropList.
     *
     * @param event The associated DropTargetDropEvent.
     */
    public void drop(DropTargetDropEvent event) {
        try {
            Transferable data = event.getTransferable();

            if (data.isDataFlavorSupported(DataFlavor.javaFileListFlavor)) {
                event.acceptDrop(DnDConstants.ACTION_COPY_OR_MOVE);

                List fileList = (List)data.getTransferData(DataFlavor.javaFileListFlavor);
                Iterator iterator = fileList.iterator();

                while (iterator.hasNext()) {
                    File file = (File)iterator.next();

                    if (file.getName().toLowerCase().endsWith(".cht")) {
                        this.parent.readCHTFile(file);
                    }
                }

                event.getDropTargetContext().dropComplete(true);
            } else {
                event.rejectDrop();
            }
        } catch (Exception e) {
            // this shouldn't really happen I think...
            // then again, I've never used DnD before...
            e.printStackTrace();
        }
    }

    /**
     * Callback when a potential drag action enters our area.
     *
     * @param event The associated DropTargetDragEvent.
     */
    public void dragEnter(DropTargetDragEvent event) {
    }

    /**
     * Callback when a potential drag action exits our area.
     *
     * @param event The associated DropTargetEvent.
     */
    public void dragExit(DropTargetEvent event) {
    }

    /**
     * Callback when a potential drag action is over our area.
     *
     * @param event The associated DropTargetDragEvent.
     */
    public void dragOver(DropTargetDragEvent event) {
    }

    /**
     * Callback when the drop action is changed.
     *
     * @param event The associated DropTargetDragEvent.
     */
    public void dropActionChanged(DropTargetDragEvent event) {
    }

    /**
     * Returns a String representation of this DropList.
     *
     * @return A String representation.
     */
    public String toString() {
        return "DropList";
    }
}
